@@ -35,7 +35,7 @@ except NameError:
 
 DESCRIPTION = "Invenio web server for development"
 USAGE_MESSAGE = "python serve.py [-bp]"
-RE_BIBFORMAT_ELEMENTS = re.compile(u"^(/modules/bibformat/lib/elements/.+\.py|/bibformat/format_elements/.+\.py)",
+RE_BIBFORMAT_ELEMENTS = re.compile(ur"^(/modules/bibformat/lib/elements/.+\.py|/bibformat/format_elements/.+\.py)",
                                    re.U|re.I)
 
 
@@ -214,29 +214,33 @@ def start_server(options, server_socket, static_files=config.STATIC_FILES):
         def pdb_on_error(f, *args, **kwargs):
             try:
                 return f(*args, **kwargs)
-            except:
+            except:  # pylint: disable-msg=W0702
+                # We catch on purpose all errors for debugging
                 pdb.post_mortem()
 
         wsgi_app = partial(pdb_on_error, wsgi_app)
 
     def timed_out_request(f, *args, **kwargs):
-        def handler(signum, frame):
+        def cb_handler(signum, frame):
             _log('info', "\033[01;31mYour request took more than %s"
                          " seconds to process\033[0m" % config.REQUEST_TIMEOUT)
-        signal.signal(signal.SIGALRM, handler)
+        signal.signal(signal.SIGALRM, cb_handler)
         signal.alarm(config.REQUEST_TIMEOUT)
         try:
             return f(*args, **kwargs)
         finally:
             signal.alarm(0)
 
-    wsgi_app = partial(timed_out_request, wsgi_app)
+    if config.REQUEST_TIMEOUT:
+        wsgi_app = partial(timed_out_request, wsgi_app)
 
     run_simple(server_socket,
                wsgi_app,
                use_debugger=True,
                use_evalex=True,
-               static_files=static)
+               static_files=static,
+               threaded=not options.single_threaded,
+               processes=1)
 
 
 def spawn_server(options, server_socket):
@@ -246,7 +250,8 @@ def spawn_server(options, server_socket):
     if pid == 0:
         try:
             start_server(options, server_socket)
-        except:
+        except:  # pylint: disable-msg=W0702
+            # We catch on purpose all errors for debugging
             print traceback.format_exc()[:-1]
             _log('info', ' * Worker crashed')
             # We do not want to free this pid because it will be killed
@@ -279,6 +284,8 @@ def parse_cli_options():
                       default=[], help='Path to Invenio installation.')
     parser.add_option('--use-console', action='store_true', dest='use_console',
                       default=False, help='Ability to open a remote console on worker')
+    parser.add_option('--single-threaded', action='store_true', dest='single_threaded',
+                      default=False, help='Disable http server threading')
     return parser.parse_args()
 
 
@@ -352,7 +359,7 @@ def setup_logging():
 def _main():
     """Script entrance"""
     setup_logging()
-    (options, args) = parse_cli_options()
+    options, dummy_args = parse_cli_options()
 
     # Override config SRC_PATH and INSTALL_PATH
     if options.src_path:
